/* Admin.c generated by valac 0.56.19, the Vala compiler
 * generated from Admin.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_DIALOGS_ADMIN_TYPE_WINDOW (tuba_dialogs_admin_window_get_type ())
#define TUBA_DIALOGS_ADMIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow))
#define TUBA_DIALOGS_ADMIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_TYPE_WINDOW))
#define TUBA_DIALOGS_ADMIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindowClass))

typedef struct _TubaDialogsAdminWindow TubaDialogsAdminWindow;
typedef struct _TubaDialogsAdminWindowClass TubaDialogsAdminWindowClass;
typedef struct _TubaDialogsAdminWindowPrivate TubaDialogsAdminWindowPrivate;

#define TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS (tuba_api_account_role_permissions_get_type ())
#define TUBA_API_ACCOUNT_ROLE_PERMISSIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS, TubaAPIAccountRolePermissions))
#define TUBA_API_ACCOUNT_ROLE_PERMISSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS, TubaAPIAccountRolePermissionsClass))
#define TUBA_API_ACCOUNT_ROLE_IS_PERMISSIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS))
#define TUBA_API_ACCOUNT_ROLE_IS_PERMISSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS))
#define TUBA_API_ACCOUNT_ROLE_PERMISSIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS, TubaAPIAccountRolePermissionsClass))

typedef struct _TubaAPIAccountRolePermissions TubaAPIAccountRolePermissions;
typedef struct _TubaAPIAccountRolePermissionsClass TubaAPIAccountRolePermissionsClass;
enum  {
	TUBA_DIALOGS_ADMIN_WINDOW_0_PROPERTY,
	TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY,
	TUBA_DIALOGS_ADMIN_WINDOW_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_admin_window_properties[TUBA_DIALOGS_ADMIN_WINDOW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_TYPE_PLACE (tuba_place_get_type ())
#define TUBA_PLACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_PLACE, TubaPlace))
#define TUBA_PLACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_PLACE, TubaPlaceClass))
#define TUBA_IS_PLACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_PLACE))
#define TUBA_IS_PLACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_PLACE))
#define TUBA_PLACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_PLACE, TubaPlaceClass))

typedef struct _TubaPlace TubaPlace;
typedef struct _TubaPlaceClass TubaPlaceClass;

#define TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE (tuba_dialogs_admin_window_place_get_type ())
#define TUBA_DIALOGS_ADMIN_WINDOW_PLACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlace))
#define TUBA_DIALOGS_ADMIN_WINDOW_PLACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlaceClass))
#define TUBA_DIALOGS_ADMIN_WINDOW_IS_PLACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE))
#define TUBA_DIALOGS_ADMIN_WINDOW_IS_PLACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE))
#define TUBA_DIALOGS_ADMIN_WINDOW_PLACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlaceClass))

typedef struct _TubaDialogsAdminWindowPlace TubaDialogsAdminWindowPlace;
typedef struct _TubaDialogsAdminWindowPlaceClass TubaDialogsAdminWindowPlaceClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE (tuba_views_admin_page_base_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBase))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE))
#define TUBA_VIEWS_ADMIN_PAGE_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BASE, TubaViewsAdminPageBaseClass))

typedef struct _TubaViewsAdminPageBase TubaViewsAdminPageBase;
typedef struct _TubaViewsAdminPageBaseClass TubaViewsAdminPageBaseClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD (tuba_views_admin_page_dashboard_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_DASHBOARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD, TubaViewsAdminPageDashboard))
#define TUBA_VIEWS_ADMIN_PAGE_DASHBOARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD, TubaViewsAdminPageDashboardClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_DASHBOARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD))
#define TUBA_VIEWS_ADMIN_PAGE_IS_DASHBOARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD))
#define TUBA_VIEWS_ADMIN_PAGE_DASHBOARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_DASHBOARD, TubaViewsAdminPageDashboardClass))

typedef struct _TubaViewsAdminPageDashboard TubaViewsAdminPageDashboard;
typedef struct _TubaViewsAdminPageDashboardClass TubaViewsAdminPageDashboardClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef void (*TubaDialogsAdminWindowPlaceOpenFuncAdmin) (TubaDialogsAdminWindow* window);

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS (tuba_views_admin_page_reports_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_REPORTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS, TubaViewsAdminPageReports))
#define TUBA_VIEWS_ADMIN_PAGE_REPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS, TubaViewsAdminPageReportsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_REPORTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_REPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS))
#define TUBA_VIEWS_ADMIN_PAGE_REPORTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_REPORTS, TubaViewsAdminPageReportsClass))

typedef struct _TubaViewsAdminPageReports TubaViewsAdminPageReports;
typedef struct _TubaViewsAdminPageReportsClass TubaViewsAdminPageReportsClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS (tuba_views_admin_page_accounts_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccounts))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccountsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ADMIN_PAGE_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_ACCOUNTS, TubaViewsAdminPageAccountsClass))

typedef struct _TubaViewsAdminPageAccounts TubaViewsAdminPageAccounts;
typedef struct _TubaViewsAdminPageAccountsClass TubaViewsAdminPageAccountsClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS (tuba_views_admin_page_blocked_emails_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmails))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmailsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_EMAILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_EMAILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_EMAILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_EMAILS, TubaViewsAdminPageBlockedEmailsClass))

typedef struct _TubaViewsAdminPageBlockedEmails TubaViewsAdminPageBlockedEmails;
typedef struct _TubaViewsAdminPageBlockedEmailsClass TubaViewsAdminPageBlockedEmailsClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS (tuba_views_admin_page_blocked_ips_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_IPS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS, TubaViewsAdminPageBlockedIPs))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_IPS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS, TubaViewsAdminPageBlockedIPsClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_IPS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS))
#define TUBA_VIEWS_ADMIN_PAGE_IS_BLOCKED_IPS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS))
#define TUBA_VIEWS_ADMIN_PAGE_BLOCKED_IPS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_BLOCKED_IPS, TubaViewsAdminPageBlockedIPsClass))

typedef struct _TubaViewsAdminPageBlockedIPs TubaViewsAdminPageBlockedIPs;
typedef struct _TubaViewsAdminPageBlockedIPsClass TubaViewsAdminPageBlockedIPsClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST (tuba_views_admin_page_federation_allow_list_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_ALLOW_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST, TubaViewsAdminPageFederationAllowList))
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_ALLOW_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST, TubaViewsAdminPageFederationAllowListClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_FEDERATION_ALLOW_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST))
#define TUBA_VIEWS_ADMIN_PAGE_IS_FEDERATION_ALLOW_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST))
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_ALLOW_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_ALLOW_LIST, TubaViewsAdminPageFederationAllowListClass))

typedef struct _TubaViewsAdminPageFederationAllowList TubaViewsAdminPageFederationAllowList;
typedef struct _TubaViewsAdminPageFederationAllowListClass TubaViewsAdminPageFederationAllowListClass;

#define TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST (tuba_views_admin_page_federation_block_list_get_type ())
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_BLOCK_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST, TubaViewsAdminPageFederationBlockList))
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_BLOCK_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST, TubaViewsAdminPageFederationBlockListClass))
#define TUBA_VIEWS_ADMIN_PAGE_IS_FEDERATION_BLOCK_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST))
#define TUBA_VIEWS_ADMIN_PAGE_IS_FEDERATION_BLOCK_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST))
#define TUBA_VIEWS_ADMIN_PAGE_FEDERATION_BLOCK_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_ADMIN_PAGE_TYPE_FEDERATION_BLOCK_LIST, TubaViewsAdminPageFederationBlockListClass))

typedef struct _TubaViewsAdminPageFederationBlockList TubaViewsAdminPageFederationBlockList;
typedef struct _TubaViewsAdminPageFederationBlockListClass TubaViewsAdminPageFederationBlockListClass;

#define TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW (tuba_views_sidebar_item_row_get_type ())
#define TUBA_VIEWS_SIDEBAR_ITEM_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW, TubaViewsSidebarItemRow))
#define TUBA_VIEWS_SIDEBAR_ITEM_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW, TubaViewsSidebarItemRowClass))
#define TUBA_VIEWS_SIDEBAR_IS_ITEM_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW))
#define TUBA_VIEWS_SIDEBAR_IS_ITEM_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW))
#define TUBA_VIEWS_SIDEBAR_ITEM_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_SIDEBAR_TYPE_ITEM_ROW, TubaViewsSidebarItemRowClass))

typedef struct _TubaViewsSidebarItemRow TubaViewsSidebarItemRow;
typedef struct _TubaViewsSidebarItemRowClass TubaViewsSidebarItemRowClass;
typedef struct _TubaPlacePrivate TubaPlacePrivate;
typedef struct _TubaDialogsAdminWindowPlacePrivate TubaDialogsAdminWindowPlacePrivate;
enum  {
	TUBA_DIALOGS_ADMIN_WINDOW_PLACE_0_PROPERTY,
	TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY,
	TUBA_DIALOGS_ADMIN_WINDOW_PLACE_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_admin_window_place_properties[TUBA_DIALOGS_ADMIN_WINDOW_PLACE_NUM_PROPERTIES];

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_API_TYPE_ACCOUNT_ROLE (tuba_api_account_role_get_type ())
#define TUBA_API_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRole))
#define TUBA_API_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))
#define TUBA_API_IS_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_IS_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_ACCOUNT_ROLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))

typedef struct _TubaAPIAccountRole TubaAPIAccountRole;
typedef struct _TubaAPIAccountRoleClass TubaAPIAccountRoleClass;

struct _TubaDialogsAdminWindow {
	AdwWindow parent_instance;
	TubaDialogsAdminWindowPrivate * priv;
	AdwNavigationSplitView* split_view;
};

struct _TubaDialogsAdminWindowClass {
	AdwWindowClass parent_class;
};

struct _TubaDialogsAdminWindowPrivate {
	GtkListBox* items;
	TubaAPIAccountRolePermissions* _admin_permissions;
	gboolean has_reports;
};

struct _TubaPlace {
	GObject parent_instance;
	TubaPlacePrivate * priv;
};

struct _TubaPlaceClass {
	GObjectClass parent_class;
};

struct _TubaDialogsAdminWindowPlace {
	TubaPlace parent_instance;
	TubaDialogsAdminWindowPlacePrivate * priv;
};

struct _TubaDialogsAdminWindowPlaceClass {
	TubaPlaceClass parent_class;
};

struct _TubaDialogsAdminWindowPlacePrivate {
	TubaDialogsAdminWindowPlaceOpenFuncAdmin _open_func_admin;
};

static gint TubaDialogsAdminWindow_private_offset;
static gpointer tuba_dialogs_admin_window_parent_class = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_dash;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_dash = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_reports;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_reports = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_accounts;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_accounts = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_blocked_email_domains;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_blocked_email_domains = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_ip_rules;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_ip_rules = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_federation_allow;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_federation_allow = NULL;
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_federation_deny;
TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_federation_deny = NULL;
static gint TubaDialogsAdminWindowPlace_private_offset;
static gpointer tuba_dialogs_admin_window_place_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_dialogs_admin_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminWindow, g_object_unref)
VALA_EXTERN GType tuba_api_account_role_permissions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountRolePermissions, g_object_unref)
VALA_EXTERN GType tuba_place_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaPlace, g_object_unref)
VALA_EXTERN GType tuba_dialogs_admin_window_place_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsAdminWindowPlace, g_object_unref)
static void _tuba_dialogs_admin_window_place_dash_lambda105_ (TubaDialogsAdminWindow* win);
VALA_EXTERN TubaViewsAdminPageDashboard* tuba_views_admin_page_dashboard_new (void);
VALA_EXTERN TubaViewsAdminPageDashboard* tuba_views_admin_page_dashboard_construct (GType object_type);
VALA_EXTERN GType tuba_views_admin_page_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBase, g_object_unref)
VALA_EXTERN GType tuba_views_admin_page_dashboard_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageDashboard, g_object_unref)
static void __tuba_dialogs_admin_window_place_dash_lambda105__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_new (void);
VALA_EXTERN TubaDialogsAdminWindowPlace* tuba_dialogs_admin_window_place_construct (GType object_type);
VALA_EXTERN void tuba_place_set_icon (TubaPlace* self,
                          const gchar* value);
VALA_EXTERN void tuba_place_set_title (TubaPlace* self,
                           const gchar* value);
VALA_EXTERN void tuba_dialogs_admin_window_place_set_open_func_admin (TubaDialogsAdminWindowPlace* self,
                                                          TubaDialogsAdminWindowPlaceOpenFuncAdmin value);
static void _tuba_dialogs_admin_window_place_reports_lambda108_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_reports_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageReports, g_object_unref)
VALA_EXTERN TubaViewsAdminPageReports* tuba_views_admin_page_reports_new (void);
VALA_EXTERN TubaViewsAdminPageReports* tuba_views_admin_page_reports_construct (GType object_type);
VALA_EXTERN void tuba_views_admin_page_base_set_admin_window (TubaViewsAdminPageBase* self,
                                                  TubaDialogsAdminWindow* value);
static void __tuba_dialogs_admin_window_place_reports_lambda108__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
static void _tuba_dialogs_admin_window_place_accounts_lambda113_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageAccounts, g_object_unref)
VALA_EXTERN TubaViewsAdminPageAccounts* tuba_views_admin_page_accounts_new (void);
VALA_EXTERN TubaViewsAdminPageAccounts* tuba_views_admin_page_accounts_construct (GType object_type);
static void __tuba_dialogs_admin_window_place_accounts_lambda113__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
static void _tuba_dialogs_admin_window_place_blocked_email_domains_lambda114_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_blocked_emails_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBlockedEmails, g_object_unref)
VALA_EXTERN TubaViewsAdminPageBlockedEmails* tuba_views_admin_page_blocked_emails_new (void);
VALA_EXTERN TubaViewsAdminPageBlockedEmails* tuba_views_admin_page_blocked_emails_construct (GType object_type);
static void __tuba_dialogs_admin_window_place_blocked_email_domains_lambda114__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
static void _tuba_dialogs_admin_window_place_ip_rules_lambda116_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_blocked_ips_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageBlockedIPs, g_object_unref)
VALA_EXTERN TubaViewsAdminPageBlockedIPs* tuba_views_admin_page_blocked_ips_new (void);
VALA_EXTERN TubaViewsAdminPageBlockedIPs* tuba_views_admin_page_blocked_ips_construct (GType object_type);
static void __tuba_dialogs_admin_window_place_ip_rules_lambda116__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
static void _tuba_dialogs_admin_window_place_federation_allow_lambda117_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_federation_allow_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageFederationAllowList, g_object_unref)
VALA_EXTERN TubaViewsAdminPageFederationAllowList* tuba_views_admin_page_federation_allow_list_new (void);
VALA_EXTERN TubaViewsAdminPageFederationAllowList* tuba_views_admin_page_federation_allow_list_construct (GType object_type);
static void __tuba_dialogs_admin_window_place_federation_allow_lambda117__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
static void _tuba_dialogs_admin_window_place_federation_deny_lambda118_ (TubaDialogsAdminWindow* win);
VALA_EXTERN GType tuba_views_admin_page_federation_block_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAdminPageFederationBlockList, g_object_unref)
VALA_EXTERN TubaViewsAdminPageFederationBlockList* tuba_views_admin_page_federation_block_list_new (void);
VALA_EXTERN TubaViewsAdminPageFederationBlockList* tuba_views_admin_page_federation_block_list_construct (GType object_type);
static void __tuba_dialogs_admin_window_place_federation_deny_lambda118__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window);
VALA_EXTERN void tuba_dialogs_admin_window_open_reports (TubaDialogsAdminWindow* self);
VALA_EXTERN TubaDialogsAdminWindowPlaceOpenFuncAdmin tuba_dialogs_admin_window_place_get_open_func_admin (TubaDialogsAdminWindowPlace* self);
static void tuba_dialogs_admin_window_on_item_activated (TubaDialogsAdminWindow* self,
                                                  GtkListBoxRow* _row);
VALA_EXTERN GType tuba_views_sidebar_item_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsSidebarItemRow, g_object_unref)
VALA_EXTERN TubaPlace* tuba_views_sidebar_item_row_get_place (TubaViewsSidebarItemRow* self);
static void _tuba_dialogs_admin_window_on_item_activated_gtk_list_box_row_activated (GtkListBox* _sender,
                                                                              GtkListBoxRow* row,
                                                                              gpointer self);
VALA_EXTERN TubaDialogsAdminWindow* tuba_dialogs_admin_window_new (void);
VALA_EXTERN TubaDialogsAdminWindow* tuba_dialogs_admin_window_construct (GType object_type);
VALA_EXTERN TubaAPIAccountRolePermissions* tuba_dialogs_admin_window_get_admin_permissions (TubaDialogsAdminWindow* self);
static void tuba_dialogs_admin_window_set_admin_permissions (TubaDialogsAdminWindow* self,
                                                      TubaAPIAccountRolePermissions* value);
VALA_EXTERN TubaPlace* tuba_place_new (void);
VALA_EXTERN TubaPlace* tuba_place_construct (GType object_type);
static void tuba_dialogs_admin_window_place_finalize (GObject * obj);
static GType tuba_dialogs_admin_window_place_get_type_once (void);
static void _vala_tuba_dialogs_admin_window_place_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec);
static void _vala_tuba_dialogs_admin_window_place_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec);
static GObject * tuba_dialogs_admin_window_constructor (GType type,
                                                 guint n_construct_properties,
                                                 GObjectConstructParam * construct_properties);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN TubaViewsSidebarItemRow* tuba_views_sidebar_item_row_new (TubaPlace* place);
VALA_EXTERN TubaViewsSidebarItemRow* tuba_views_sidebar_item_row_construct (GType object_type,
                                                                TubaPlace* place);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN gboolean tuba_instance_account_get_admin_mode (TubaInstanceAccount* self);
VALA_EXTERN GType tuba_api_account_role_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountRole, g_object_unref)
VALA_EXTERN TubaAPIAccountRole* tuba_api_account_get_role (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_account_role_get_permissions (TubaAPIAccountRole* self);
VALA_EXTERN TubaAPIAccountRolePermissions* tuba_api_account_role_permissions_new_from_string (const gchar* bitmask);
VALA_EXTERN TubaAPIAccountRolePermissions* tuba_api_account_role_permissions_construct_from_string (GType object_type,
                                                                                        const gchar* bitmask);
VALA_EXTERN gboolean tuba_api_account_role_permissions_get_admin (TubaAPIAccountRolePermissions* self);
VALA_EXTERN gboolean tuba_api_account_role_permissions_get_reports (TubaAPIAccountRolePermissions* self);
VALA_EXTERN gboolean tuba_api_account_role_permissions_get_users (TubaAPIAccountRolePermissions* self);
VALA_EXTERN gboolean tuba_api_account_role_permissions_get_federation (TubaAPIAccountRolePermissions* self);
VALA_EXTERN gboolean tuba_api_account_role_permissions_get_blocks (TubaAPIAccountRolePermissions* self);
static void tuba_dialogs_admin_window_finalize (GObject * obj);
static GType tuba_dialogs_admin_window_get_type_once (void);
static void _vala_tuba_dialogs_admin_window_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_tuba_dialogs_admin_window_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);

static inline gpointer
tuba_dialogs_admin_window_get_instance_private (TubaDialogsAdminWindow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaDialogsAdminWindow_private_offset);
}

static void
_tuba_dialogs_admin_window_place_dash_lambda105_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaViewsAdminPageDashboard* _tmp1_;
	TubaViewsAdminPageDashboard* _tmp2_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = tuba_views_admin_page_dashboard_new ();
	g_object_ref_sink (_tmp1_);
	_tmp2_ = _tmp1_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp2_);
	_g_object_unref0 (_tmp2_);
}

static void
__tuba_dialogs_admin_window_place_dash_lambda105__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_dash_lambda105_ (window);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_dialogs_admin_window_place_reports_lambda108_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageReports* _tmp2_ = NULL;
	TubaViewsAdminPageReports* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_reports_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_reports_lambda108__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_reports_lambda108_ (window);
}

static void
_tuba_dialogs_admin_window_place_accounts_lambda113_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageAccounts* _tmp2_ = NULL;
	TubaViewsAdminPageAccounts* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_accounts_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_accounts_lambda113__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_accounts_lambda113_ (window);
}

static void
_tuba_dialogs_admin_window_place_blocked_email_domains_lambda114_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageBlockedEmails* _tmp2_ = NULL;
	TubaViewsAdminPageBlockedEmails* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_blocked_emails_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_blocked_email_domains_lambda114__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_blocked_email_domains_lambda114_ (window);
}

static void
_tuba_dialogs_admin_window_place_ip_rules_lambda116_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageBlockedIPs* _tmp2_ = NULL;
	TubaViewsAdminPageBlockedIPs* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_blocked_ips_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_ip_rules_lambda116__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_ip_rules_lambda116_ (window);
}

static void
_tuba_dialogs_admin_window_place_federation_allow_lambda117_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageFederationAllowList* _tmp2_ = NULL;
	TubaViewsAdminPageFederationAllowList* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_federation_allow_list_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_federation_allow_lambda117__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_federation_allow_lambda117_ (window);
}

static void
_tuba_dialogs_admin_window_place_federation_deny_lambda118_ (TubaDialogsAdminWindow* win)
{
	AdwNavigationSplitView* _tmp0_;
	TubaDialogsAdminWindow* _tmp1_;
	TubaViewsAdminPageFederationBlockList* _tmp2_ = NULL;
	TubaViewsAdminPageFederationBlockList* _tmp3_;
	g_return_if_fail (win != NULL);
	_tmp0_ = win->split_view;
	_tmp1_ = _g_object_ref0 (win);
	_tmp2_ = tuba_views_admin_page_federation_block_list_new ();
	tuba_views_admin_page_base_set_admin_window ((TubaViewsAdminPageBase*) _tmp2_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	g_object_ref_sink (_tmp2_);
	_tmp3_ = _tmp2_;
	adw_navigation_split_view_set_content (_tmp0_, (AdwNavigationPage*) _tmp3_);
	_g_object_unref0 (_tmp3_);
}

static void
__tuba_dialogs_admin_window_place_federation_deny_lambda118__tuba_dialogs_admin_window_place_open_func_admin (TubaDialogsAdminWindow* window)
{
	_tuba_dialogs_admin_window_place_federation_deny_lambda118_ (window);
}

void
tuba_dialogs_admin_window_open_reports (TubaDialogsAdminWindow* self)
{
	g_return_if_fail (self != NULL);
	if (self->priv->has_reports) {
		TubaDialogsAdminWindowPlace* _tmp0_;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp1_ = NULL;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp2_;
		GtkListBox* _tmp3_;
		GtkListBox* _tmp4_;
		GtkListBoxRow* _tmp5_;
		_tmp0_ = tuba_dialogs_admin_window_place_reports;
		_tmp1_ = tuba_dialogs_admin_window_place_get_open_func_admin (_tmp0_);
		_tmp2_ = _tmp1_;
		_tmp2_ (self);
		_tmp3_ = self->priv->items;
		_tmp4_ = self->priv->items;
		_tmp5_ = gtk_list_box_get_row_at_index (_tmp4_, 1);
		gtk_list_box_select_row (_tmp3_, _tmp5_);
	}
}

static void
tuba_dialogs_admin_window_on_item_activated (TubaDialogsAdminWindow* self,
                                             GtkListBoxRow* _row)
{
	TubaViewsSidebarItemRow* row = NULL;
	TubaViewsSidebarItemRow* _tmp0_;
	TubaViewsSidebarItemRow* _tmp1_;
	TubaDialogsAdminWindowPlace* place = NULL;
	TubaViewsSidebarItemRow* _tmp2_;
	TubaPlace* _tmp3_;
	TubaPlace* _tmp4_;
	TubaDialogsAdminWindowPlace* _tmp5_;
	gboolean _tmp6_ = FALSE;
	TubaDialogsAdminWindowPlace* _tmp7_;
	AdwNavigationSplitView* _tmp14_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (_row != NULL);
	_tmp0_ = _g_object_ref0 (TUBA_VIEWS_SIDEBAR_IS_ITEM_ROW (_row) ? ((TubaViewsSidebarItemRow*) _row) : NULL);
	row = _tmp0_;
	_tmp1_ = row;
	if (_tmp1_ == NULL) {
		_g_object_unref0 (row);
		return;
	}
	_tmp2_ = row;
	_tmp3_ = tuba_views_sidebar_item_row_get_place (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _g_object_ref0 (TUBA_DIALOGS_ADMIN_WINDOW_IS_PLACE (_tmp4_) ? ((TubaDialogsAdminWindowPlace*) _tmp4_) : NULL);
	place = _tmp5_;
	_tmp7_ = place;
	if (_tmp7_ != NULL) {
		TubaDialogsAdminWindowPlace* _tmp8_;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp9_ = NULL;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp10_;
		_tmp8_ = place;
		_tmp9_ = tuba_dialogs_admin_window_place_get_open_func_admin (_tmp8_);
		_tmp10_ = _tmp9_;
		_tmp6_ = _tmp10_ != NULL;
	} else {
		_tmp6_ = FALSE;
	}
	if (_tmp6_) {
		TubaDialogsAdminWindowPlace* _tmp11_;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp12_ = NULL;
		TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp13_;
		_tmp11_ = place;
		_tmp12_ = tuba_dialogs_admin_window_place_get_open_func_admin (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp13_ (self);
	}
	_tmp14_ = self->split_view;
	adw_navigation_split_view_set_show_content (_tmp14_, TRUE);
	_g_object_unref0 (place);
	_g_object_unref0 (row);
}

static void
_tuba_dialogs_admin_window_on_item_activated_gtk_list_box_row_activated (GtkListBox* _sender,
                                                                         GtkListBoxRow* row,
                                                                         gpointer self)
{
	tuba_dialogs_admin_window_on_item_activated ((TubaDialogsAdminWindow*) self, row);
}

TubaDialogsAdminWindow*
tuba_dialogs_admin_window_construct (GType object_type)
{
	TubaDialogsAdminWindow * self = NULL;
	self = (TubaDialogsAdminWindow*) g_object_new (object_type, NULL);
	return self;
}

TubaDialogsAdminWindow*
tuba_dialogs_admin_window_new (void)
{
	return tuba_dialogs_admin_window_construct (TUBA_DIALOGS_ADMIN_TYPE_WINDOW);
}

TubaAPIAccountRolePermissions*
tuba_dialogs_admin_window_get_admin_permissions (TubaDialogsAdminWindow* self)
{
	TubaAPIAccountRolePermissions* result;
	TubaAPIAccountRolePermissions* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_admin_permissions;
	result = _tmp0_;
	return result;
}

static void
tuba_dialogs_admin_window_set_admin_permissions (TubaDialogsAdminWindow* self,
                                                 TubaAPIAccountRolePermissions* value)
{
	TubaAPIAccountRolePermissions* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_dialogs_admin_window_get_admin_permissions (self);
	if (old_value != value) {
		TubaAPIAccountRolePermissions* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_admin_permissions);
		self->priv->_admin_permissions = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_admin_window_properties[TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY]);
	}
}

static inline gpointer
tuba_dialogs_admin_window_place_get_instance_private (TubaDialogsAdminWindowPlace* self)
{
	return G_STRUCT_MEMBER_P (self, TubaDialogsAdminWindowPlace_private_offset);
}

TubaDialogsAdminWindowPlace*
tuba_dialogs_admin_window_place_construct (GType object_type)
{
	TubaDialogsAdminWindowPlace * self = NULL;
	self = (TubaDialogsAdminWindowPlace*) tuba_place_construct (object_type);
	return self;
}

TubaDialogsAdminWindowPlace*
tuba_dialogs_admin_window_place_new (void)
{
	return tuba_dialogs_admin_window_place_construct (TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE);
}

TubaDialogsAdminWindowPlaceOpenFuncAdmin
tuba_dialogs_admin_window_place_get_open_func_admin (TubaDialogsAdminWindowPlace* self)
{
	TubaDialogsAdminWindowPlaceOpenFuncAdmin result;
	TubaDialogsAdminWindowPlaceOpenFuncAdmin _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_open_func_admin;
	result = _tmp0_;
	return result;
}

void
tuba_dialogs_admin_window_place_set_open_func_admin (TubaDialogsAdminWindowPlace* self,
                                                     TubaDialogsAdminWindowPlaceOpenFuncAdmin value)
{
	TubaDialogsAdminWindowPlaceOpenFuncAdmin old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_dialogs_admin_window_place_get_open_func_admin (self);
	if (old_value != value) {
		self->priv->_open_func_admin = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_admin_window_place_properties[TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY]);
	}
}

static void
tuba_dialogs_admin_window_place_class_init (TubaDialogsAdminWindowPlaceClass * klass,
                                            gpointer klass_data)
{
	tuba_dialogs_admin_window_place_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaDialogsAdminWindowPlace_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_dialogs_admin_window_place_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_dialogs_admin_window_place_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_dialogs_admin_window_place_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY, tuba_dialogs_admin_window_place_properties[TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY] = g_param_spec_pointer ("open-func-admin", "open-func-admin", "open-func-admin", G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_dialogs_admin_window_place_instance_init (TubaDialogsAdminWindowPlace * self,
                                               gpointer klass)
{
	self->priv = tuba_dialogs_admin_window_place_get_instance_private (self);
}

static void
tuba_dialogs_admin_window_place_finalize (GObject * obj)
{
	TubaDialogsAdminWindowPlace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlace);
	G_OBJECT_CLASS (tuba_dialogs_admin_window_place_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_admin_window_place_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsAdminWindowPlaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_admin_window_place_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsAdminWindowPlace), 0, (GInstanceInitFunc) tuba_dialogs_admin_window_place_instance_init, NULL };
	GType tuba_dialogs_admin_window_place_type_id;
	tuba_dialogs_admin_window_place_type_id = g_type_register_static (TUBA_TYPE_PLACE, "TubaDialogsAdminWindowPlace", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaDialogsAdminWindowPlace_private_offset = g_type_add_instance_private (tuba_dialogs_admin_window_place_type_id, sizeof (TubaDialogsAdminWindowPlacePrivate));
	return tuba_dialogs_admin_window_place_type_id;
}

GType
tuba_dialogs_admin_window_place_get_type (void)
{
	static GType tuba_dialogs_admin_window_place_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_admin_window_place_type_id__once)) {
		GType tuba_dialogs_admin_window_place_type_id;
		tuba_dialogs_admin_window_place_type_id = tuba_dialogs_admin_window_place_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_admin_window_place_type_id__once, tuba_dialogs_admin_window_place_type_id);
	}
	return tuba_dialogs_admin_window_place_type_id__once;
}

static void
_vala_tuba_dialogs_admin_window_place_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec)
{
	TubaDialogsAdminWindowPlace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlace);
	switch (property_id) {
		case TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY:
		g_value_set_pointer (value, tuba_dialogs_admin_window_place_get_open_func_admin (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_dialogs_admin_window_place_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec)
{
	TubaDialogsAdminWindowPlace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_ADMIN_WINDOW_TYPE_PLACE, TubaDialogsAdminWindowPlace);
	switch (property_id) {
		case TUBA_DIALOGS_ADMIN_WINDOW_PLACE_OPEN_FUNC_ADMIN_PROPERTY:
		tuba_dialogs_admin_window_place_set_open_func_admin (self, g_value_get_pointer (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static GObject *
tuba_dialogs_admin_window_constructor (GType type,
                                       guint n_construct_properties,
                                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaDialogsAdminWindow * self;
	TubaApplication* _tmp0_;
	TubaDialogsMainWindow* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	GtkListBox* _tmp3_;
	TubaDialogsAdminWindowPlace* _tmp4_;
	TubaViewsSidebarItemRow* _tmp5_;
	TubaViewsSidebarItemRow* _tmp6_;
	gboolean _tmp7_ = FALSE;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	TubaAccountStore* _tmp10_;
	TubaInstanceAccount* _tmp11_;
	TubaInstanceAccount* _tmp12_;
	AdwNavigationSplitView* _tmp91_;
	TubaViewsAdminPageDashboard* _tmp92_;
	TubaViewsAdminPageDashboard* _tmp93_;
	parent_class = G_OBJECT_CLASS (tuba_dialogs_admin_window_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow);
	_tmp0_ = tuba_app;
	_tmp1_ = tuba_application_get_main_window (_tmp0_);
	_tmp2_ = _tmp1_;
	gtk_window_set_transient_for ((GtkWindow*) self, (GtkWindow*) _tmp2_);
	gtk_window_set_modal ((GtkWindow*) self, TRUE);
	_tmp3_ = self->priv->items;
	_tmp4_ = tuba_dialogs_admin_window_place_dash;
	_tmp5_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp4_);
	g_object_ref_sink (_tmp5_);
	_tmp6_ = _tmp5_;
	gtk_list_box_append (_tmp3_, (GtkWidget*) _tmp6_);
	_g_object_unref0 (_tmp6_);
	_tmp10_ = tuba_accounts;
	_tmp11_ = tuba_account_store_get_active (_tmp10_);
	_tmp12_ = _tmp11_;
	if (_tmp12_ != NULL) {
		TubaAccountStore* _tmp13_;
		TubaInstanceAccount* _tmp14_;
		TubaInstanceAccount* _tmp15_;
		gboolean _tmp16_;
		gboolean _tmp17_;
		_tmp13_ = tuba_accounts;
		_tmp14_ = tuba_account_store_get_active (_tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = tuba_instance_account_get_admin_mode (_tmp15_);
		_tmp17_ = _tmp16_;
		_tmp9_ = _tmp17_;
	} else {
		_tmp9_ = FALSE;
	}
	if (_tmp9_) {
		TubaAccountStore* _tmp18_;
		TubaInstanceAccount* _tmp19_;
		TubaInstanceAccount* _tmp20_;
		TubaAPIAccountRole* _tmp21_;
		TubaAPIAccountRole* _tmp22_;
		_tmp18_ = tuba_accounts;
		_tmp19_ = tuba_account_store_get_active (_tmp18_);
		_tmp20_ = _tmp19_;
		_tmp21_ = tuba_api_account_get_role ((TubaAPIAccount*) _tmp20_);
		_tmp22_ = _tmp21_;
		_tmp8_ = _tmp22_ != NULL;
	} else {
		_tmp8_ = FALSE;
	}
	if (_tmp8_) {
		TubaAccountStore* _tmp23_;
		TubaInstanceAccount* _tmp24_;
		TubaInstanceAccount* _tmp25_;
		TubaAPIAccountRole* _tmp26_;
		TubaAPIAccountRole* _tmp27_;
		const gchar* _tmp28_;
		const gchar* _tmp29_;
		_tmp23_ = tuba_accounts;
		_tmp24_ = tuba_account_store_get_active (_tmp23_);
		_tmp25_ = _tmp24_;
		_tmp26_ = tuba_api_account_get_role ((TubaAPIAccount*) _tmp25_);
		_tmp27_ = _tmp26_;
		_tmp28_ = tuba_api_account_role_get_permissions (_tmp27_);
		_tmp29_ = _tmp28_;
		_tmp7_ = _tmp29_ != NULL;
	} else {
		_tmp7_ = FALSE;
	}
	if (_tmp7_) {
		TubaAccountStore* _tmp30_;
		TubaInstanceAccount* _tmp31_;
		TubaInstanceAccount* _tmp32_;
		TubaAPIAccountRole* _tmp33_;
		TubaAPIAccountRole* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		TubaAPIAccountRolePermissions* _tmp37_;
		TubaAPIAccountRolePermissions* _tmp38_;
		gboolean _tmp39_ = FALSE;
		TubaAPIAccountRolePermissions* _tmp40_;
		gboolean _tmp41_;
		gboolean _tmp42_;
		gboolean _tmp50_ = FALSE;
		TubaAPIAccountRolePermissions* _tmp51_;
		gboolean _tmp52_;
		gboolean _tmp53_;
		gboolean _tmp61_ = FALSE;
		TubaAPIAccountRolePermissions* _tmp62_;
		gboolean _tmp63_;
		gboolean _tmp64_;
		gboolean _tmp76_ = FALSE;
		TubaAPIAccountRolePermissions* _tmp77_;
		gboolean _tmp78_;
		gboolean _tmp79_;
		_tmp30_ = tuba_accounts;
		_tmp31_ = tuba_account_store_get_active (_tmp30_);
		_tmp32_ = _tmp31_;
		_tmp33_ = tuba_api_account_get_role ((TubaAPIAccount*) _tmp32_);
		_tmp34_ = _tmp33_;
		_tmp35_ = tuba_api_account_role_get_permissions (_tmp34_);
		_tmp36_ = _tmp35_;
		_tmp37_ = tuba_api_account_role_permissions_new_from_string (_tmp36_);
		_tmp38_ = _tmp37_;
		tuba_dialogs_admin_window_set_admin_permissions (self, _tmp38_);
		_g_object_unref0 (_tmp38_);
		_tmp40_ = self->priv->_admin_permissions;
		_tmp41_ = tuba_api_account_role_permissions_get_admin (_tmp40_);
		_tmp42_ = _tmp41_;
		if (_tmp42_) {
			_tmp39_ = TRUE;
		} else {
			TubaAPIAccountRolePermissions* _tmp43_;
			gboolean _tmp44_;
			gboolean _tmp45_;
			_tmp43_ = self->priv->_admin_permissions;
			_tmp44_ = tuba_api_account_role_permissions_get_reports (_tmp43_);
			_tmp45_ = _tmp44_;
			_tmp39_ = _tmp45_;
		}
		if (_tmp39_) {
			GtkListBox* _tmp46_;
			TubaDialogsAdminWindowPlace* _tmp47_;
			TubaViewsSidebarItemRow* _tmp48_;
			TubaViewsSidebarItemRow* _tmp49_;
			_tmp46_ = self->priv->items;
			_tmp47_ = tuba_dialogs_admin_window_place_reports;
			_tmp48_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp47_);
			g_object_ref_sink (_tmp48_);
			_tmp49_ = _tmp48_;
			gtk_list_box_append (_tmp46_, (GtkWidget*) _tmp49_);
			_g_object_unref0 (_tmp49_);
			self->priv->has_reports = TRUE;
		}
		_tmp51_ = self->priv->_admin_permissions;
		_tmp52_ = tuba_api_account_role_permissions_get_admin (_tmp51_);
		_tmp53_ = _tmp52_;
		if (_tmp53_) {
			_tmp50_ = TRUE;
		} else {
			TubaAPIAccountRolePermissions* _tmp54_;
			gboolean _tmp55_;
			gboolean _tmp56_;
			_tmp54_ = self->priv->_admin_permissions;
			_tmp55_ = tuba_api_account_role_permissions_get_users (_tmp54_);
			_tmp56_ = _tmp55_;
			_tmp50_ = _tmp56_;
		}
		if (_tmp50_) {
			GtkListBox* _tmp57_;
			TubaDialogsAdminWindowPlace* _tmp58_;
			TubaViewsSidebarItemRow* _tmp59_;
			TubaViewsSidebarItemRow* _tmp60_;
			_tmp57_ = self->priv->items;
			_tmp58_ = tuba_dialogs_admin_window_place_accounts;
			_tmp59_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp58_);
			g_object_ref_sink (_tmp59_);
			_tmp60_ = _tmp59_;
			gtk_list_box_append (_tmp57_, (GtkWidget*) _tmp60_);
			_g_object_unref0 (_tmp60_);
		}
		_tmp62_ = self->priv->_admin_permissions;
		_tmp63_ = tuba_api_account_role_permissions_get_admin (_tmp62_);
		_tmp64_ = _tmp63_;
		if (_tmp64_) {
			_tmp61_ = TRUE;
		} else {
			TubaAPIAccountRolePermissions* _tmp65_;
			gboolean _tmp66_;
			gboolean _tmp67_;
			_tmp65_ = self->priv->_admin_permissions;
			_tmp66_ = tuba_api_account_role_permissions_get_federation (_tmp65_);
			_tmp67_ = _tmp66_;
			_tmp61_ = _tmp67_;
		}
		if (_tmp61_) {
			GtkListBox* _tmp68_;
			TubaDialogsAdminWindowPlace* _tmp69_;
			TubaViewsSidebarItemRow* _tmp70_;
			TubaViewsSidebarItemRow* _tmp71_;
			GtkListBox* _tmp72_;
			TubaDialogsAdminWindowPlace* _tmp73_;
			TubaViewsSidebarItemRow* _tmp74_;
			TubaViewsSidebarItemRow* _tmp75_;
			_tmp68_ = self->priv->items;
			_tmp69_ = tuba_dialogs_admin_window_place_federation_allow;
			_tmp70_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp69_);
			g_object_ref_sink (_tmp70_);
			_tmp71_ = _tmp70_;
			gtk_list_box_append (_tmp68_, (GtkWidget*) _tmp71_);
			_g_object_unref0 (_tmp71_);
			_tmp72_ = self->priv->items;
			_tmp73_ = tuba_dialogs_admin_window_place_federation_deny;
			_tmp74_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp73_);
			g_object_ref_sink (_tmp74_);
			_tmp75_ = _tmp74_;
			gtk_list_box_append (_tmp72_, (GtkWidget*) _tmp75_);
			_g_object_unref0 (_tmp75_);
		}
		_tmp77_ = self->priv->_admin_permissions;
		_tmp78_ = tuba_api_account_role_permissions_get_admin (_tmp77_);
		_tmp79_ = _tmp78_;
		if (_tmp79_) {
			_tmp76_ = TRUE;
		} else {
			TubaAPIAccountRolePermissions* _tmp80_;
			gboolean _tmp81_;
			gboolean _tmp82_;
			_tmp80_ = self->priv->_admin_permissions;
			_tmp81_ = tuba_api_account_role_permissions_get_blocks (_tmp80_);
			_tmp82_ = _tmp81_;
			_tmp76_ = _tmp82_;
		}
		if (_tmp76_) {
			GtkListBox* _tmp83_;
			TubaDialogsAdminWindowPlace* _tmp84_;
			TubaViewsSidebarItemRow* _tmp85_;
			TubaViewsSidebarItemRow* _tmp86_;
			GtkListBox* _tmp87_;
			TubaDialogsAdminWindowPlace* _tmp88_;
			TubaViewsSidebarItemRow* _tmp89_;
			TubaViewsSidebarItemRow* _tmp90_;
			_tmp83_ = self->priv->items;
			_tmp84_ = tuba_dialogs_admin_window_place_blocked_email_domains;
			_tmp85_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp84_);
			g_object_ref_sink (_tmp85_);
			_tmp86_ = _tmp85_;
			gtk_list_box_append (_tmp83_, (GtkWidget*) _tmp86_);
			_g_object_unref0 (_tmp86_);
			_tmp87_ = self->priv->items;
			_tmp88_ = tuba_dialogs_admin_window_place_ip_rules;
			_tmp89_ = tuba_views_sidebar_item_row_new ((TubaPlace*) _tmp88_);
			g_object_ref_sink (_tmp89_);
			_tmp90_ = _tmp89_;
			gtk_list_box_append (_tmp87_, (GtkWidget*) _tmp90_);
			_g_object_unref0 (_tmp90_);
		}
	}
	_tmp91_ = self->split_view;
	_tmp92_ = tuba_views_admin_page_dashboard_new ();
	g_object_ref_sink (_tmp92_);
	_tmp93_ = _tmp92_;
	adw_navigation_split_view_set_content (_tmp91_, (AdwNavigationPage*) _tmp93_);
	_g_object_unref0 (_tmp93_);
	return obj;
}

static void
tuba_dialogs_admin_window_class_init (TubaDialogsAdminWindowClass * klass,
                                      gpointer klass_data)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	TubaDialogsAdminWindowPlace* _tmp2_ = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	TubaDialogsAdminWindowPlace* _tmp5_ = NULL;
	gchar* _tmp6_;
	gchar* _tmp7_;
	TubaDialogsAdminWindowPlace* _tmp8_ = NULL;
	gchar* _tmp9_;
	gchar* _tmp10_;
	TubaDialogsAdminWindowPlace* _tmp11_ = NULL;
	gchar* _tmp12_;
	gchar* _tmp13_;
	TubaDialogsAdminWindowPlace* _tmp14_ = NULL;
	gchar* _tmp15_;
	gchar* _tmp16_;
	TubaDialogsAdminWindowPlace* _tmp17_ = NULL;
	gchar* _tmp18_;
	gchar* _tmp19_;
	TubaDialogsAdminWindowPlace* _tmp20_ = NULL;
	tuba_dialogs_admin_window_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaDialogsAdminWindow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_dialogs_admin_window_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_dialogs_admin_window_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_dialogs_admin_window_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_dialogs_admin_window_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY, tuba_dialogs_admin_window_properties[TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY] = g_param_spec_object ("admin-permissions", "admin-permissions", "admin-permissions", TUBA_API_ACCOUNT_ROLE_TYPE_PERMISSIONS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/dev/geopjr/Tuba/ui/dialogs/admin_dashboard.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "split_view", FALSE, G_STRUCT_OFFSET (TubaDialogsAdminWindow, split_view));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "items", FALSE, TubaDialogsAdminWindow_private_offset + G_STRUCT_OFFSET (TubaDialogsAdminWindowPrivate, items));
	_tmp0_ = g_strdup ("tuba-user-home-symbolic");
	_tmp1_ = g_strdup (_ ("Dashboard"));
	_tmp2_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp2_, _tmp0_);
	_g_free0 (_tmp0_);
	tuba_place_set_title ((TubaPlace*) _tmp2_, _tmp1_);
	_g_free0 (_tmp1_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp2_, __tuba_dialogs_admin_window_place_dash_lambda105__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_dash = _tmp2_;
	_tmp3_ = g_strdup ("tuba-build-alt-symbolic");
	_tmp4_ = g_strdup (_ ("Reports"));
	_tmp5_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp5_, _tmp3_);
	_g_free0 (_tmp3_);
	tuba_place_set_title ((TubaPlace*) _tmp5_, _tmp4_);
	_g_free0 (_tmp4_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp5_, __tuba_dialogs_admin_window_place_reports_lambda108__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_reports = _tmp5_;
	_tmp6_ = g_strdup ("tuba-people-symbolic");
	_tmp7_ = g_strdup (_ ("Accounts"));
	_tmp8_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp8_, _tmp6_);
	_g_free0 (_tmp6_);
	tuba_place_set_title ((TubaPlace*) _tmp8_, _tmp7_);
	_g_free0 (_tmp7_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp8_, __tuba_dialogs_admin_window_place_accounts_lambda113__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_accounts = _tmp8_;
	_tmp9_ = g_strdup ("tuba-mail-unread-symbolic");
	_tmp10_ = g_strdup (_ ("Blocked E-mail Domains"));
	_tmp11_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp11_, _tmp9_);
	_g_free0 (_tmp9_);
	tuba_place_set_title ((TubaPlace*) _tmp11_, _tmp10_);
	_g_free0 (_tmp10_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp11_, __tuba_dialogs_admin_window_place_blocked_email_domains_lambda114__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_blocked_email_domains = _tmp11_;
	_tmp12_ = g_strdup ("tuba-network-server-symbolic");
	_tmp13_ = g_strdup (_ ("IP Rules"));
	_tmp14_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp14_, _tmp12_);
	_g_free0 (_tmp12_);
	tuba_place_set_title ((TubaPlace*) _tmp14_, _tmp13_);
	_g_free0 (_tmp13_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp14_, __tuba_dialogs_admin_window_place_ip_rules_lambda116__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_ip_rules = _tmp14_;
	_tmp15_ = g_strdup ("tuba-check-round-outline-symbolic");
	_tmp16_ = g_strdup (_ ("Federation Allowlist"));
	_tmp17_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp17_, _tmp15_);
	_g_free0 (_tmp15_);
	tuba_place_set_title ((TubaPlace*) _tmp17_, _tmp16_);
	_g_free0 (_tmp16_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp17_, __tuba_dialogs_admin_window_place_federation_allow_lambda117__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_federation_allow = _tmp17_;
	_tmp18_ = g_strdup ("tuba-cross-large-symbolic");
	_tmp19_ = g_strdup (_ ("Federation Blocklist"));
	_tmp20_ = tuba_dialogs_admin_window_place_new ();
	tuba_place_set_icon ((TubaPlace*) _tmp20_, _tmp18_);
	_g_free0 (_tmp18_);
	tuba_place_set_title ((TubaPlace*) _tmp20_, _tmp19_);
	_g_free0 (_tmp19_);
	tuba_dialogs_admin_window_place_set_open_func_admin (_tmp20_, __tuba_dialogs_admin_window_place_federation_deny_lambda118__tuba_dialogs_admin_window_place_open_func_admin);
	tuba_dialogs_admin_window_place_federation_deny = _tmp20_;
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_item_activated", G_CALLBACK(_tuba_dialogs_admin_window_on_item_activated_gtk_list_box_row_activated));
}

static void
tuba_dialogs_admin_window_instance_init (TubaDialogsAdminWindow * self,
                                         gpointer klass)
{
	self->priv = tuba_dialogs_admin_window_get_instance_private (self);
	self->priv->has_reports = FALSE;
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
tuba_dialogs_admin_window_finalize (GObject * obj)
{
	TubaDialogsAdminWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow);
	g_debug ("Admin.vala:15: Destroying Admin Dialog");
	_g_object_unref0 (self->priv->_admin_permissions);
	G_OBJECT_CLASS (tuba_dialogs_admin_window_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_admin_window_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsAdminWindowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_admin_window_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsAdminWindow), 0, (GInstanceInitFunc) tuba_dialogs_admin_window_instance_init, NULL };
	GType tuba_dialogs_admin_window_type_id;
	tuba_dialogs_admin_window_type_id = g_type_register_static (adw_window_get_type (), "TubaDialogsAdminWindow", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaDialogsAdminWindow_private_offset = g_type_add_instance_private (tuba_dialogs_admin_window_type_id, sizeof (TubaDialogsAdminWindowPrivate));
	return tuba_dialogs_admin_window_type_id;
}

GType
tuba_dialogs_admin_window_get_type (void)
{
	static GType tuba_dialogs_admin_window_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_admin_window_type_id__once)) {
		GType tuba_dialogs_admin_window_type_id;
		tuba_dialogs_admin_window_type_id = tuba_dialogs_admin_window_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_admin_window_type_id__once, tuba_dialogs_admin_window_type_id);
	}
	return tuba_dialogs_admin_window_type_id__once;
}

static void
_vala_tuba_dialogs_admin_window_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	TubaDialogsAdminWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow);
	switch (property_id) {
		case TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY:
		g_value_set_object (value, tuba_dialogs_admin_window_get_admin_permissions (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_dialogs_admin_window_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	TubaDialogsAdminWindow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_ADMIN_TYPE_WINDOW, TubaDialogsAdminWindow);
	switch (property_id) {
		case TUBA_DIALOGS_ADMIN_WINDOW_ADMIN_PERMISSIONS_PROPERTY:
		tuba_dialogs_admin_window_set_admin_permissions (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

